@@ -3,10 +3,10 @@ use warnings;
 
 package Dancer2::Plugin::UnicodeNormalize;
 {
-    $Dancer2::Plugin::UnicodeNormalize::VERSION = '0.035';
+    $Dancer2::Plugin::UnicodeNormalize::VERSION = '0.04';
 }
 
-use Dancer2::Plugin 0.150;
+use Dancer2::Plugin 0.202000;
 use Unicode::Normalize;
 
 on_plugin_import {
@@ -18,12 +18,13 @@ on_plugin_import {
         Dancer2::Core::Hook->new(
             name => 'before',
             code => sub {
+                my $app = shift;
                 # perhaps better ways to check for Plugin2 but this works
                 if ( $dsl->can('execute_plugin_hook')) {
                     # Plugin2  - fetch fresh config on each run
                     $settings = plugin_setting;
                 }
-                for (@{$settings->{'exclude'}}) { return if $dsl->app->request->path =~ /$_/ }
+                for (@{$settings->{'exclude'}}) { return if $app->request->path =~ /$_/ }
 
                 my $form = $settings->{'form'} || 'NFC';
                 my $normalizer = Unicode::Normalize->can($form);
@@ -34,11 +35,20 @@ on_plugin_import {
                 }
 
                 for (qw/query body route/) {
-                    my $p = $dsl->app->request->params($_);
+                    my $p = $app->request->params($_);
                     next unless $p;
                     %{$p} = map { $_ => $normalizer->($p->{$_}) } grep { $p->{$_} } keys %{$p};
                 }
-                $dsl->app->request->_build_params;
+                $app->request->_build_params;
+
+                if ( $app->request->can("body_parameters") ) {
+                    for (qw/query_parameters body_parameters route_parameters/) {
+                        my $p = $app->request->$_;
+                        for my $key ( $p->keys ) {
+                            $p->set( $key, map { $_ ? $normalizer->($_) : $_} $p->get_all($key) );
+                        }
+                    }
+                }
             },
         ),
     );
@@ -57,7 +67,7 @@ Dancer2::Plugin::UnicodeNormalize - Normalize incoming Unicode parameters
 
 =head1 VERSION
 
-Version 0.035
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -71,11 +81,6 @@ silently before processing each route. By default, we use Unicode Normalization
 Form C - this is usually what you want. Other forms can be selected, see:
 L</"CONFIGURATION">.
 
-B<** NOTE **> This has been updated to build against Dancer2 0.200000 but
-operations do not yet apply to newer parameter access methods, query_parameters,
-body_parameters and route_parameters. This will be fixed in the next release.
-
-
 This plugin was inspired by L<Mojolicious::Plugin::UnicodeNormalize>. For
 information on why Unicode Normalization is important, please see:
 
